@@ -65,7 +65,7 @@ DrumGizmoPlugin::DrumGizmoPlugin()
 	init();
 
 	drumgizmo = std::make_shared<DrumGizmo>(settings, output, input);
-	resizeWindow(width, height);
+	resizeWindow(GUI::MainWindow::main_width, GUI::MainWindow::main_height);
 	drumgizmo->setFreeWheel(true);
 	drumgizmo->setSamplerate(44100);
 	drumgizmo->setFrameSize(2048);
@@ -199,7 +199,7 @@ public:
 	}
 
 	// From Canvas:
-	GUI::PixelBufferAlpha& GetPixelBuffer() override
+	GUI::PixelBufferAlpha& getPixelBuffer() override
 	{
 		return pixbuf;
 	}
@@ -235,10 +235,15 @@ void DrumGizmoPlugin::onInlineRedraw(std::size_t width,
 	bool nofl_changed = settingsGetter.number_of_files_loaded.hasChanged();
 	bool dls_changed = settingsGetter.drumkit_load_status.hasChanged();
 
+	bool in_progress =
+		settingsGetter.number_of_files_loaded.getValue() <
+		settingsGetter.number_of_files.getValue();
+
 	bool context_needs_update =
 	    !context.data || context.width != width || context.height != height;
 	bool bar_needs_update =
-		nof_changed || nofl_changed || dls_changed || context_needs_update;
+		nof_changed || nofl_changed || dls_changed || context_needs_update |
+		in_progress; // Always update while loading to prevent flickering.
 	bool image_needs_update = inline_image_first_draw || context_needs_update;
 	// TODO: settingsGetter.inline_image_filename.hasChanged();
 	bool something_needs_update =
@@ -254,15 +259,15 @@ void DrumGizmoPlugin::onInlineRedraw(std::size_t width,
 		InlineCanvas canvas(context);
 		GUI::Painter painter(canvas);
 
+		double progress =
+			(double)settingsGetter.number_of_files_loaded.getValue() /
+			(double)settingsGetter.number_of_files.getValue();
+
 		if(show_bar && bar_needs_update)
 		{
 			box.setSize(context.width, bar_height);
 			painter.drawImage(0, height - bar_height, box);
 
-			double progress =
-				(double)settingsGetter.number_of_files_loaded.getValue() /
-				(double)settingsGetter.number_of_files.getValue();
-
 			int brd = 4;
 			int val = (width - (2 * brd)) * progress;
 
@@ -312,7 +317,7 @@ bool DrumGizmoPlugin::hasGUI()
 void* DrumGizmoPlugin::createWindow(void* parent)
 {
 	plugin_gui = std::make_shared<GUI::MainWindow>(settings, parent);
-	resizeWindow(width, height);
+	resizeWindow(GUI::MainWindow::main_width, GUI::MainWindow::main_height);
 	onShowWindow();
 
 	return plugin_gui->getNativeWindowHandle();
@@ -607,6 +612,8 @@ std::string DrumGizmoPlugin::ConfigStringIO::get()
 		float2str(settings.velocity_randomiser_weight.load()) + "</value>\n"
 		"  <value name=\"enable_resampling\">" +
 		bool2str(settings.enable_resampling.load()) + "</value>\n"
+		"  <value name=\"resampling_quality\">" +
+		float2str(settings.resampling_quality.load()) + "</value>\n"
 		"  <value name=\"disk_cache_upper_limit\">" +
 		int2str(settings.disk_cache_upper_limit.load()) + "</value>\n"
 		"  <value name=\"disk_cache_chunk_size\">" +
@@ -628,6 +635,28 @@ std::string DrumGizmoPlugin::ConfigStringIO::get()
 		float2str(settings.latency_stddev.load()) + "</value>\n"
 		"  <value name=\"latency_regain\">" +
 		float2str(settings.latency_regain.load()) + "</value>\n"
+		"  <value name=\"enable_powermap\">" +
+		bool2str(settings.enable_powermap.load()) + "</value>\n"
+		"  <value name=\"powermap_fixed0_x\">" +
+		float2str(settings.powermap_fixed0_x.load()) + "</value>\n"
+		"  <value name=\"powermap_fixed0_y\">" +
+		float2str(settings.powermap_fixed0_y.load()) + "</value>\n"
+		"  <value name=\"powermap_fixed1_x\">" +
+		float2str(settings.powermap_fixed1_x.load()) + "</value>\n"
+		"  <value name=\"powermap_fixed1_y\">" +
+		float2str(settings.powermap_fixed1_y.load()) + "</value>\n"
+		"  <value name=\"powermap_fixed2_x\">" +
+		float2str(settings.powermap_fixed2_x.load()) + "</value>\n"
+		"  <value name=\"powermap_fixed2_y\">" +
+		float2str(settings.powermap_fixed2_y.load()) + "</value>\n"
+		"  <value name=\"powermap_shelf\">" +
+		bool2str(settings.powermap_shelf.load()) + "</value>\n"
+		"  <value name=\"enable_voice_limit\">" +
+		bool2str(settings.enable_voice_limit.load()) + "</value>\n"
+		"  <value name=\"voice_limit_max\">" +
+		int2str(settings.voice_limit_max.load()) + "</value>\n"
+		"  <value name=\"voice_limit_rampdown\">" +
+		float2str(settings.voice_limit_rampdown.load()) + "</value>\n"
 		"</config>";
 }
 
@@ -692,6 +721,11 @@ bool DrumGizmoPlugin::ConfigStringIO::set(std::string config_string)
 		settings.enable_resampling.store(p.value("enable_resampling") == "true");
 	}
 
+	if(p.value("resampling_quality") != "")
+	{
+		settings.resampling_quality.store(str2float(p.value("resampling_quality")));
+	}
+
 	if(p.value("disk_cache_upper_limit") != "")
 	{
 		settings.disk_cache_upper_limit.store(str2ll(p.value("disk_cache_upper_limit")));
@@ -743,6 +777,61 @@ bool DrumGizmoPlugin::ConfigStringIO::set(std::string config_string)
 		settings.latency_regain.store(str2float(p.value("latency_regain")));
 	}
 
+	if(p.value("enable_powermap") != "")
+	{
+		settings.enable_powermap.store(p.value("enable_powermap") == "true");
+	}
+
+	if(p.value("powermap_fixed0_x") != "")
+	{
+		settings.powermap_fixed0_x.store(str2float(p.value("powermap_fixed0_x")));
+	}
+
+	if(p.value("powermap_fixed0_y") != "")
+	{
+		settings.powermap_fixed0_y.store(str2float(p.value("powermap_fixed0_y")));
+	}
+
+	if(p.value("powermap_fixed1_x") != "")
+	{
+		settings.powermap_fixed1_x.store(str2float(p.value("powermap_fixed1_x")));
+	}
+
+	if(p.value("powermap_fixed1_y") != "")
+	{
+		settings.powermap_fixed1_y.store(str2float(p.value("powermap_fixed1_y")));
+	}
+
+	if(p.value("powermap_fixed2_x") != "")
+	{
+		settings.powermap_fixed2_x.store(str2float(p.value("powermap_fixed2_x")));
+	}
+
+	if(p.value("powermap_fixed2_y") != "")
+	{
+		settings.powermap_fixed2_y.store(str2float(p.value("powermap_fixed2_y")));
+	}
+
+	if(p.value("powermap_shelf") != "")
+	{
+		settings.powermap_shelf.store(p.value("powermap_shelf") == "true");
+	}
+
+	if(p.value("enable_voice_limit") != "")
+	{
+		settings.enable_voice_limit.store(p.value("enable_voice_limit") == "true");
+	}
+
+	if(p.value("voice_limit_max") != "")
+	{
+		settings.voice_limit_max.store(str2int(p.value("voice_limit_max")));
+	}
+
+	if(p.value("voice_limit_rampdown") != "")
+	{
+		settings.voice_limit_rampdown.store(str2float(p.value("voice_limit_rampdown")));
+	}
+
 	std::string newkit = p.value("drumkitfile");
 	if(newkit != "")
 	{
