@@ -26,6 +26,8 @@
  */
 #pragma once
 
+#include <config.h>
+
 #include <memory>
 
 #ifdef LV2
@@ -37,6 +39,7 @@
 #endif
 
 #include <drumgizmo.h>
+#include <uitranslation.h>
 #include <audioinputenginemidi.h>
 #include <audiooutputengine.h>
 #include <mainwindow.h>
@@ -111,6 +114,7 @@ public:
 	void closeWindow() override;
 
 private:
+
 	class Input
 		: public AudioInputEngineMidi
 	{
@@ -212,6 +216,7 @@ private:
 	GUI::Image inline_display_image{":resources/logo.png"};
 	bool inline_image_first_draw{true};
 
-	static constexpr std::size_t width{750};
-	static constexpr std::size_t height{613};
+#ifdef WITH_NLS
+	UITranslation translation;
+#endif // WITH_NLS
 };
