@@ -27,9 +27,32 @@
 #include "abouttab.h"
 
 #include <version.h>
+#include <translation.h>
 
 #include "utf8.h"
 
+namespace
+{
+std::string getLocalizedFile(const std::string& file)
+{
+	auto language = Translation::getISO639LanguageName();
+	std::string file_localized = file + "." + language;
+	GUI::Resource resource_localized{file_localized};
+	if(resource_localized.valid())
+	{
+		return resource_localized.data();
+	}
+
+	GUI::Resource resource{file};
+	if(resource.valid())
+	{
+		return resource.data();
+	}
+
+	return "";
+}
+}
+
 namespace GUI
 {
 
@@ -55,48 +78,48 @@ std::string AboutTab::getAboutText()
 	std::string about_text;
 
 	// About
-	about_text.append(
+	about_text.append(_(
 	"=============\n"
 	"             About\n"
 	"=============\n"
-	"\n");
-	about_text.append(about.data());
+	"\n"));
+	about_text.append(UTF8().toLatin1(getLocalizedFile(":../ABOUT")));
 
 	// Version
-	about_text.append(
+	about_text.append(_(
 	"\n"
 	"=============\n"
 	"            Version\n"
 	"=============\n"
-	"\n");
+	"\n"));
 	about_text.append(std::string(VERSION) + "\n");
 
 	// Bugs
-	about_text.append(
+	about_text.append(_(
 	"\n"
 	"=============\n"
 	"            Bugs\n"
 	"=============\n"
-	"\n");
-	about_text.append(bugs.data());
+	"\n"));
+	about_text.append(UTF8().toLatin1(getLocalizedFile(":../BUGS")));
 
 	// Authors
-	about_text.append(
+	about_text.append(_(
 	"\n"
 	"=============\n"
 	"            Authors\n"
 	"=============\n"
-	"\n");
-	about_text.append(UTF8().toLatin1(authors.data()));
+	"\n"));
+	about_text.append(UTF8().toLatin1(getLocalizedFile(":../AUTHORS")));
 
 	// GPL
-	about_text.append(
+	about_text.append(_(
 	"\n"
 	"=============\n"
 	"            License\n"
 	"=============\n"
-	"\n");
-	about_text.append(gpl.data());
+	"\n"));
+	about_text.append(UTF8().toLatin1(getLocalizedFile(":../COPYING")));
 
 	return about_text;
 }
