@@ -111,7 +111,7 @@ void ComboBox::repaintEvent(RepaintEvent* repaintEvent)
 	box.setSize(w, h);
 	p.drawImage(0, 0, box);
 
-	p.setColour(Colour(183.0/255.0, 219.0/255.0 , 255.0/255.0, 1));
+	p.setColour(Colour(183.0f/255.0f, 219.0f/255.0f, 255.0/255.0f, 1.0f));
 	p.drawText(BORDER - 4 + 3, height()/2+5 + 1 + 1, font, _text);
 
 	//  p.setColour(Colour(1, 1, 1));
