@@ -27,6 +27,7 @@
 #pragma once
 
 #include <cstdlib>
+#include <cstdint>
 
 namespace GUI
 {
@@ -42,6 +43,10 @@ public:
 	virtual std::size_t height() const = 0;
 
 	virtual const Colour& getPixel(std::size_t x, std::size_t y) const = 0;
+	virtual const std::uint8_t* line(std::size_t y,
+	                                 std::size_t x_offset = 0) const = 0;
+
+	virtual bool hasAlpha() const = 0;
 };
 
 } // GUI::
