@@ -38,6 +38,8 @@
 #include "timingframecontent.h"
 #include "sampleselectionframecontent.h"
 #include "visualizerframecontent.h"
+#include "powerwidget.h"
+#include "voicelimitframecontent.h"
 
 struct Settings;
 class SettingsNotifier;
@@ -63,10 +65,12 @@ private:
 	void bleedcontrolOnChange(bool on);
 	void resamplingOnChange(bool on);
 	void timingOnChange(bool on);
+	void powerOnChange(bool on);
+	void voicelimitOnChange(bool status);
 
 	Image logo{":resources/logo.png"};
 
-	GridLayout layout{this, 2, 49};
+	GridLayout layout{this, 2, 64};
 
 	FrameWidget drumkit_frame{this, false};
 	FrameWidget status_frame{this, false};
@@ -77,6 +81,8 @@ private:
 	FrameWidget timing_frame{this, true, true};
 	FrameWidget sampleselection_frame{this, false, true};
 	FrameWidget visualizer_frame{this, false, true};
+	FrameWidget power_frame{this, true, true};
+	FrameWidget voicelimit_frame{this, true, true};
 
 	DrumkitframeContent drumkitframe_content;
 	StatusframeContent statusframe_content;
@@ -87,6 +93,8 @@ private:
 	TimingframeContent timingframe_content;
 	SampleselectionframeContent sampleselectionframe_content;
 	VisualizerframeContent visualizerframe_content;
+	PowerWidget powerframe_content;
+	VoiceLimitFrameContent voicelimit_content;
 
 	void add(std::string const& title, FrameWidget& frame, Widget& content,
 	         std::size_t height, int column);
