@@ -49,14 +49,15 @@ public:
 
 	void drawLine(int x1, int y1, int x2, int y2);
 	void drawText(int x, int y, const Font& font, const std::string& text,
-	              bool nocolour = false);
+	              bool nocolour = false, bool rotate = false);
 	void drawRectangle(int x1, int y1, int x2, int y2);
 	void drawFilledRectangle(int x1, int y1, int x2, int y2);
 	void drawPoint(int x, int y);
 	void drawCircle(int x, int y, double r);
 	void drawFilledCircle(int x, int y, int r);
 	void drawImage(int x, int y, const Drawable& image);
-	void drawRestrictedImage(int x0, int y0, Colour const& colour, const Drawable& image);
+	void drawRestrictedImage(int x0, int y0, const Colour& restriction_colour,
+	                         const Drawable& image);
 	void drawImageStretched(int x, int y, const Drawable& image,
 	                        int width, int height);
 
@@ -86,9 +87,6 @@ public:
 	void clear();
 
 private:
-	bool has_restriction{false};
-	Colour restriction_colour;
-
 	PixelBufferAlpha& pixbuf;
 	Colour colour;
 };
