@@ -29,6 +29,10 @@
 #include "colour.h"
 
 #include <cstddef>
+#include <cstdint>
+#include <vector>
+
+#include "guievent.h"
 
 namespace GUI
 {
@@ -41,13 +45,13 @@ public:
 
 	void realloc(std::size_t width, std::size_t height);
 
-	void setPixel(std::size_t x, std::size_t y,
-	              unsigned char red,
-	              unsigned char green,
-	              unsigned char blue,
-	              unsigned char alpha);
+	void blendLine(std::size_t x, std::size_t y,
+	               const std::uint8_t* line, std::size_t len);
 
-	unsigned char* buf{nullptr};
+	Rect updateBuffer(std::vector<class PixelBufferAlpha*>& pixel_buffers);
+
+	std::vector<std::uint8_t> buf_data;
+	std::uint8_t* buf{nullptr};
 	std::size_t width{0};
 	std::size_t height{0};
 };
@@ -61,28 +65,23 @@ public:
 
 	void realloc(std::size_t width, std::size_t height);
 
-	void setPixel(std::size_t x, std::size_t y,
-	              unsigned char red,
-	              unsigned char green,
-	              unsigned char blue,
-	              unsigned char alpha);
+	void clear();
 
-	void addPixel(std::size_t x, std::size_t y,
-	              unsigned char red,
-	              unsigned char green,
-	              unsigned char blue,
-	              unsigned char alpha);
+	void setPixel(std::size_t x, std::size_t y, const Colour& c);
+
+	void writeLine(std::size_t x, std::size_t y,
+	               const std::uint8_t* line, std::size_t len);
+	void blendLine(std::size_t x, std::size_t y,
+	               const std::uint8_t* line, std::size_t len);
 
 	void addPixel(std::size_t x, std::size_t y, const Colour& c);
 
-	void pixel(std::size_t x, std::size_t y,
-	           unsigned char* red,
-	           unsigned char* green,
-	           unsigned char* blue,
-	           unsigned char* alpha) const;
+	const Colour& pixel(std::size_t x, std::size_t y) const;
 
-	bool managed{false};
-	unsigned char* buf{nullptr};
+	const std::uint8_t* getLine(std::size_t x, std::size_t y) const;
+
+	std::vector<std::uint8_t> buf_data;
+	std::uint8_t* buf{nullptr};
 	std::size_t width{0};
 	std::size_t height{0};
 	int x{0};
