@@ -11,21 +11,20 @@
  *  This file is part of DrumGizmo.
  *
  *  DrumGizmo is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  DrumGizmo is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#ifndef __DRUMGIZMO_RESOURCE_H__
-#define __DRUMGIZMO_RESOURCE_H__
+#pragma once
 
 #include <string>
 
@@ -33,21 +32,19 @@ namespace GUI {
 
 class Resource {
 public:
-  Resource(std::string name);
+	Resource(const std::string& name);
 
-  const char *data();
-  size_t size();
+	const char* data();
+	size_t size();
 
-  bool valid();
+	bool valid();
 
-private:
-  std::string e_data;
-  bool is_valid;
-  bool is_internal;
-  const char *i_data;
-  size_t i_size;
+protected:
+	std::string externalData;
+	bool isValid{false};
+	bool isInternal{false};
+	const char *internalData{nullptr};
+	size_t internalSize{0};
 };
 
-};
-
-#endif/*__DRUMGIZMO_RESOURCE_H__*/
+} // GUI::
