@@ -26,6 +26,8 @@
  */
 #include "statusframecontent.h"
 
+#include <translation.h>
+
 namespace GUI
 {
 
@@ -67,14 +69,14 @@ void StatusframeContent::resize(std::size_t width, std::size_t height)
 void StatusframeContent::updateContent()
 {
 	text_field.setText(
-		"Drumkit status:   " + drumkit_load_status + "\n"
-		// "Midimap status: " + midimap_load_status + "\n"
-		"Drumkit name:   " + drumkit_name + "\n"
-		"Drumkit description:   " + drumkit_description + "\n"
-		// "Drumkit version:   " + drumkit_version + "\n"
-		"Session buffer size:   " + buffer_size + "\n"
-		"Number of underruns: " + number_of_underruns + "\n" +
-		"Messages:\n" + messages
+		 _("Drumkit status:   ") + drumkit_load_status + "\n" +
+		//  _("Midimap status: ") + midimap_load_status + "\n" +
+		 _("Drumkit name:   ") + drumkit_name + "\n" +
+		 _("Drumkit description:   ") + drumkit_description + "\n" +
+		//  _("Drumkit version:   ") + drumkit_version + "\n" +
+		 _("Session buffer size:   ") + buffer_size + "\n" +
+		 _("Number of underruns: ") + number_of_underruns + "\n" +
+		 _("Messages:\n") + messages
 	);
 }
 
@@ -83,16 +85,16 @@ void StatusframeContent::updateDrumkitLoadStatus(LoadStatus load_status)
 	switch(load_status)
 	{
 	case LoadStatus::Idle:
-		drumkit_load_status = "No Kit Loaded";
+		drumkit_load_status = _("No Kit Loaded");
 		break;
 	case LoadStatus::Loading:
-		drumkit_load_status = "Loading...";
+		drumkit_load_status = _("Loading...");
 		break;
 	case LoadStatus::Done:
-		drumkit_load_status = "Ready";
+		drumkit_load_status = _("Ready");
 		break;
 	case LoadStatus::Error:
-		drumkit_load_status = "Error";
+		drumkit_load_status = _("Error");
 		break;
 	}
 
@@ -125,16 +127,16 @@ void StatusframeContent::updateMidimapLoadStatus(LoadStatus load_status)
 	switch(load_status)
 	{
 	case LoadStatus::Idle:
-		midimap_load_status = "No Midimap Loaded";
+		midimap_load_status = _("No Midimap Loaded");
 		break;
 	case LoadStatus::Loading:
-		midimap_load_status = "Loading...";
+		midimap_load_status = _("Loading...");
 		break;
 	case LoadStatus::Done:
-		midimap_load_status = "Ready";
+		midimap_load_status = _("Ready");
 		break;
 	case LoadStatus::Error:
-		midimap_load_status = "Error";
+		midimap_load_status = _("Error");
 		break;
 	}
 
