@@ -133,4 +133,15 @@ const Colour& TexturedBox::getPixel(std::size_t x, std::size_t y) const
 	return outOfRange;
 }
 
+const std::uint8_t* TexturedBox::line(std::size_t y, std::size_t x_offset) const
+{
+	// TODO: Gather line into temporary buffer?
+	return nullptr;
+}
+
+bool TexturedBox::hasAlpha() const
+{
+	return true;
+}
+
 } // GUI::
