@@ -35,10 +35,14 @@
 
 #include <hugin.hpp>
 
-AudioFile::AudioFile(const std::string& filename, std::size_t filechannel)
+#include "channel.h"
+
+AudioFile::AudioFile(const std::string& filename, std::size_t filechannel,
+                     InstrumentChannel* instrument_channel)
 	: filename(filename)
 	, filechannel(filechannel)
 	, magic{this}
+	, instrument_channel(instrument_channel)
 {
 }
 
@@ -69,7 +73,7 @@ void AudioFile::unload()
 
 #define BUFFER_SIZE 4096
 
-void AudioFile::load(std::size_t sample_limit)
+void AudioFile::load(LogFunction logger, std::size_t sample_limit)
 {
 	// Make sure we don't unload the object while loading it...
 	std::lock_guard<std::mutex> guard(mutex);
@@ -85,12 +89,22 @@ void AudioFile::load(std::size_t sample_limit)
 	{
 		ERR(audiofile,"SNDFILE Error (%s): %s\n",
 		    filename.c_str(), sf_strerror(fh));
+		if(logger)
+		{
+			logger(LogLevel::Warning, "Could not load '" + filename +
+			       "': " + sf_strerror(fh));
+		}
 		return;
 	}
 
 	if(sf_info.channels < 1)
 	{
 		// This should never happen but lets check just in case.
+		if(logger)
+		{
+			logger(LogLevel::Warning, "Could not load '" + filename +
+			       "': no audio channels available.");
+		}
 		return;
 	}
 
@@ -112,6 +126,11 @@ void AudioFile::load(std::size_t sample_limit)
 		// check filechannel exists
 		if(filechannel >= (std::size_t)sf_info.channels)
 		{
+			if(logger)
+			{
+				logger(LogLevel::Warning, "Audio file '" + filename +
+				       "' does no have " + std::to_string(filechannel + 1) + " channels.");
+			}
 			filechannel = sf_info.channels - 1;
 		}
 
@@ -150,3 +169,14 @@ bool AudioFile::isLoaded() const
 {
 	return is_loaded;
 }
+
+main_state_t AudioFile::mainState() const
+{
+	if(instrument_channel == nullptr)
+	{
+		DEBUG(audiofile, "no instrument_channel!");
+		return main_state_t::unset;
+	}
+
+	return instrument_channel->main;
+}
