@@ -26,14 +26,9 @@
  */
 #include "configfile.h"
 
-#include <stdio.h>
-#include <errno.h>
-#include <string.h>
-#include <stdlib.h>
-
 #include <sys/stat.h>
-#include <sys/types.h>
 
+#include "directory.h"
 #include "platform.h"
 
 #if DG_PLATFORM == DG_PLATFORM_WINDOWS
@@ -46,55 +41,57 @@
 
 #include <hugin.hpp>
 
+namespace
+{
+
 #if DG_PLATFORM == DG_PLATFORM_WINDOWS
-#define SEP "\\"
+const std::string sep = "\\";
 #else
-#define SEP "/"
+const std::string sep = "/";
 #endif
 
-#define CONFIGDIRNAME ".drumgizmo"
-
-/**
- * Return the path containing the config files.
- */
-static std::string getConfigPath()
-{
 #if DG_PLATFORM == DG_PLATFORM_WINDOWS
+const std::string config_dir_name = "DrumGizmo";
+#else
+const std::string config_dir_name = ".drumgizmo";
+#endif
+
+
+// Return the path containing the config files.
+std::string getConfigPath()
+{
+	// TODO: Move this utility function as a static function into directory.cc/h at some point?
 	std::string configpath;
+#if DG_PLATFORM == DG_PLATFORM_WINDOWS
 	TCHAR szPath[256];
-	if(SUCCEEDED(SHGetFolderPath(
-	       NULL, CSIDL_APPDATA | CSIDL_FLAG_CREATE, NULL, 0, szPath)))
+	if(SHGetFolderPath(NULL, CSIDL_APPDATA | CSIDL_FLAG_CREATE, NULL, 0, szPath) == S_OK)
 	{
 		configpath = szPath;
 	}
 #else
-	std::string configpath = getenv("HOME");
+	configpath = getenv("HOME");
 #endif
-	configpath += SEP;
-	configpath += CONFIGDIRNAME;
+	configpath += sep;
+	configpath += config_dir_name;
 
 	return configpath;
 }
 
-/**
- * Calling this makes sure that the config path exists
- */
-static bool createConfigPath()
+// Calling this makes sure that the config path exists
+bool createConfigPath()
 {
-	std::string configpath = getConfigPath();
+	const std::string configpath = getConfigPath();
 
-	struct stat st;
-	if(stat(configpath.c_str(), &st) != 0)
+	if(!Directory::isDir(configpath))
 	{
 		DEBUG(configfile, "No configuration exists, creating directory '%s'\n",
 		      configpath.c_str());
 #if DG_PLATFORM == DG_PLATFORM_WINDOWS
 		if(mkdir(configpath.c_str()) < 0)
-		{
 #else
 		if(mkdir(configpath.c_str(), 0755) < 0)
-		{
 #endif
+		{
 			DEBUG(configfile, "Could not create config directory\n");
 		}
 
@@ -104,24 +101,27 @@ static bool createConfigPath()
 	return true;
 }
 
-ConfigFile::ConfigFile(std::string const& filename)
+} // end anonymous namespace
+
+ConfigFile::ConfigFile(const std::string& filename)
 	: filename(filename)
-	, fp(nullptr)
 {
 }
 
 ConfigFile::~ConfigFile()
 {
-	if (fp != nullptr)
+	if (current_file.is_open())
 	{
 		DEBUG(configfile, "File has not been closed by the client...\n");
+		current_file.close();
 	}
 }
 
+// TODO: Make this return a homemade error variant when we have this project-wide.
 bool ConfigFile::load()
 {
 	DEBUG(configfile, "Loading config file...\n");
-	if(!open("r"))
+	if(!open(std::ios_base::in))
 	{
 		return false;
 	}
@@ -129,20 +129,15 @@ bool ConfigFile::load()
 	values.clear();
 
 	std::string line;
-	while(true)
+	while(std::getline(current_file, line))
 	{
-		line = readLine();
-
-		if(line == "")
-			break;
-
 		if(!parseLine(line))
 		{
 			return false;
 		}
 	}
 
-	close();
+	current_file.close();
 
 	return true;
 }
@@ -151,20 +146,21 @@ bool ConfigFile::save()
 {
 	DEBUG(configfile, "Saving configuration...\n");
 
-	createConfigPath();
-
-	if(!open("w"))
+	if(!createConfigPath())
 	{
 		return false;
 	}
 
-	std::map<std::string, std::string>::iterator v = values.begin();
-	for(; v != values.end(); ++v)
+	if(!open(std::ios_base::out))
 	{
-		fprintf(fp, "%s:%s\n", v->first.c_str(), v->second.c_str());
+		return false;
 	}
 
-	close();
+	for(const auto& value: values)
+	{
+		current_file << value.first << " = " << "\"" << value.second << "\"" << std::endl;
+	}
+	current_file.close();
 
 	return true;
 }
@@ -185,65 +181,24 @@ void ConfigFile::setValue(const std::string& key, const std::string& value)
 	values[key] = value;
 }
 
-bool ConfigFile::open(std::string mode)
+bool ConfigFile::open(std::ios_base::openmode mode)
 {
-	if(fp)
+	if(current_file.is_open())
 	{
-		close();
+		current_file.close();
 	}
 
-	std::string configpath = getConfigPath();
+	std::string const full_filename = getConfigPath() + sep + filename;
 
-	std::string configfile = configpath;
-	configfile += SEP;
-	configfile += filename;
+	DEBUG(configfile, "Opening config file '%s'\n", full_filename.c_str());
+	current_file.open(full_filename, mode);
 
-	DEBUG(configfile, "Opening config file '%s'\n", configfile.c_str());
-	fp = fopen(configfile.c_str(), mode.c_str());
-
-	if(!fp)
-	{
-		return false;
-	}
-
-	return true;
-}
-
-void ConfigFile::close()
-{
-	fclose(fp);
-	fp = nullptr;
-}
-
-std::string ConfigFile::readLine()
-{
-	if(!fp)
-	{
-		return "";
-	}
-
-	std::string line;
-
-	char buf[1024];
-	while(!feof(fp))
-	{
-		char* s = fgets(buf, sizeof(buf), fp);
-		if(s)
-		{
-			line += buf;
-			if(buf[strlen(buf) - 1] == '\n')
-				break;
-		}
-	}
-
-	return line;
+	return current_file.is_open();
 }
 
 bool ConfigFile::parseLine(const std::string& line)
 {
-	std::string key;
-	std::string value;
-	enum
+	enum class State
 	{
 		before_key,
 		in_key,
@@ -253,49 +208,60 @@ bool ConfigFile::parseLine(const std::string& line)
 		in_value_single_quoted,
 		in_value_double_quoted,
 		after_value,
-	} state = before_key;
+	};
 
-	for(std::size_t p = 0; p < line.size(); ++p)
+	// For empty lines, we parse them fine but don't do anything.
+	if(line == "")
 	{
+		return true;
+	}
+
+	std::string key;
+	std::string value;
+	State state = State::before_key;
+
+	for(std::size_t pos = 0; pos < line.size(); ++pos)
+	{
+		auto c = line[pos];
 		switch(state)
 		{
-		case before_key:
-			if(line[p] == '#')
+		case State::before_key:
+			if(c == '#')
 			{
 				// Comment: Ignore line.
-				p = line.size();
+				pos = line.size();
 				continue;
 			}
-			if(std::isspace(line[p]))
+			if(std::isspace(c))
 			{
 				continue;
 			}
-			key += line[p];
-			state = in_key;
+			key += c;
+			state = State::in_key;
 			break;
 
-		case in_key:
-			if(std::isspace(line[p]))
+		case State::in_key:
+			if(std::isspace(c))
 			{
-				state = after_key;
+				state = State::after_key;
 				continue;
 			}
-			if(line[p] == ':' || line[p] == '=')
+			if(c == ':' || c == '=')
 			{
-				state = before_value;
+				state = State::before_value;
 				continue;
 			}
-			key += line[p];
+			key += c;
 			break;
 
-		case after_key:
-			if(std::isspace(line[p]))
+		case State::after_key:
+			if(std::isspace(c))
 			{
 				continue;
 			}
-			if(line[p] == ':' || line[p] == '=')
+			if(c == ':' || c == '=')
 			{
-				state = before_value;
+				state = State::before_value;
 				continue;
 			}
 			ERR(configfile,
@@ -304,68 +270,68 @@ bool ConfigFile::parseLine(const std::string& line)
 			    line.c_str());
 			return false;
 
-		case before_value:
-			if(std::isspace(line[p]))
+		case State::before_value:
+			if(std::isspace(c))
 			{
 				continue;
 			}
-			if(line[p] == '\'')
+			if(c == '\'')
 			{
-				state = in_value_single_quoted;
+				state = State::in_value_single_quoted;
 				continue;
 			}
-			if(line[p] == '"')
+			if(c == '"')
 			{
-				state = in_value_double_quoted;
+				state = State::in_value_double_quoted;
 				continue;
 			}
-			value += line[p];
-			state = in_value;
+			value += c;
+			state = State::in_value;
 			break;
 
-		case in_value:
-			if(std::isspace(line[p]))
+		case State::in_value:
+			if(std::isspace(c))
 			{
-				state = after_value;
+				state = State::after_value;
 				continue;
 			}
-			if(line[p] == '#')
+			if(c == '#')
 			{
 				// Comment: Ignore the rest of the line.
-				p = line.size();
-				state = after_value;
+				pos = line.size();
+				state = State::after_value;
 				continue;
 			}
-			value += line[p];
+			value += c;
 			break;
 
-		case in_value_single_quoted:
-			if(line[p] == '\'')
+		case State::in_value_single_quoted:
+			if(c == '\'')
 			{
-				state = after_value;
+				state = State::after_value;
 				continue;
 			}
-			value += line[p];
+			value += c;
 			break;
 
-		case in_value_double_quoted:
-			if(line[p] == '"')
+		case State::in_value_double_quoted:
+			if(c == '"')
 			{
-				state = after_value;
+				state = State::after_value;
 				continue;
 			}
-			value += line[p];
+			value += c;
 			break;
 
-		case after_value:
-			if(std::isspace(line[p]))
+		case State::after_value:
+			if(std::isspace(c))
 			{
 				continue;
 			}
-			if(line[p] == '#')
+			if(c == '#')
 			{
 				// Comment: Ignore the rest of the line.
-				p = line.size();
+				pos = line.size();
 				continue;
 			}
 			ERR(configfile,
@@ -376,7 +342,7 @@ bool ConfigFile::parseLine(const std::string& line)
 		}
 	}
 
-	if(state == before_key)
+	if(state == State::before_key)
 	{
 		// Line did not contain any data (empty or comment)
 		return true;
@@ -384,7 +350,7 @@ bool ConfigFile::parseLine(const std::string& line)
 
 	// If state == in_value_XXX_quoted here, the string was not terminated.
 	// If state == before_value it means that the value is empty.
-	if(state != after_value && state != in_value && state != before_value)
+	if(state != State::after_value && state != State::in_value && state != State::before_value)
 	{
 		ERR(configfile, "Malformed line: '%s'", line.c_str());
 		return false;
