@@ -28,28 +28,26 @@
 
 #include <string>
 #include <map>
-#include <stdio.h>
+#include <fstream>
 
 class ConfigFile
 {
 public:
-	ConfigFile(std::string const& filename);
+	ConfigFile(const std::string& filename);
 	virtual ~ConfigFile();
 
 	virtual bool load();
 	virtual bool save();
 
-	virtual std::string getValue(const std::string& key) const;
-	virtual void setValue(const std::string& key, const std::string& value);
+	std::string getValue(const std::string& key) const;
+	void setValue(const std::string& key, const std::string& value);
 
 protected:
 	std::map<std::string, std::string> values;
 	std::string filename;
+	std::fstream current_file;
 
-	virtual bool open(std::string mode);
-	void close();
+	virtual bool open(std::ios_base::openmode mode);
 	std::string readLine();
 	bool parseLine(const std::string& line);
-
-	FILE* fp;
 };
