@@ -46,15 +46,25 @@ DrumGizmo::DrumGizmo(Settings& settings,
 	, oe(o)
 	, ie(i)
 	, audio_cache(settings)
-	, input_processor(settings, kit, activeevents, rand)
+	, input_processor(settings, kit, events_ds, rand)
 	, settings(settings)
 	, settings_getter(settings)
 {
 	audio_cache.init(10000); // start thread
 	events.reserve(1000);
 	loader.init();
-	setSamplerate(44100.0f);
+	setSamplerate(44100.0f, settings.resampling_quality.load());
 	settings_getter.audition_counter.hasChanged(); // Reset audition_counter
+
+	config.load();
+	if(config.defaultMidimap != "" && settings.midimap_file.load() == "")
+	{
+		settings.midimap_file.store(config.defaultMidimap);
+	}
+	if(config.defaultKit != "" && settings.drumkit_file.load() == "")
+	{
+		settings.drumkit_file.store(config.defaultKit);
+	}
 }
 
 DrumGizmo::~DrumGizmo()
@@ -114,10 +124,15 @@ bool DrumGizmo::run(size_t pos, sample_t *samples, size_t nsamples)
 		enable_resampling = settings_getter.enable_resampling.getValue();
 	}
 
-	if(settings_getter.drumkit_samplerate.hasChanged())
 	{
-		settings_getter.drumkit_samplerate.getValue(); // stage new value
-		setSamplerate(settings.samplerate.load());
+		auto sample_rate_changed = settings_getter.drumkit_samplerate.hasChanged();
+		auto resampling_quality_changed = settings_getter.resampling_quality.hasChanged();
+		if(sample_rate_changed || resampling_quality_changed)
+		{
+			settings_getter.drumkit_samplerate.getValue(); // stage new value
+			setSamplerate(settings.samplerate.load(),
+			              settings_getter.resampling_quality.getValue());
+		}
 	}
 
 	setFrameSize(nsamples);
@@ -211,10 +226,10 @@ bool DrumGizmo::run(size_t pos, sample_t *samples, size_t nsamples)
 				internal = true;
 			}
 
-			zita[c].out_data = buf;
-			zita[c].out_count = nsamples;
+			zita[c].set_out_data(buf);
+			zita[c].set_out_count(nsamples);
 
-			if(zita[c].inp_count > 0)
+			if(zita[c].get_inp_count() > 0)
 			{
 				// Samples left from last iteration, process that one first
 				zita[c].process();
@@ -222,12 +237,12 @@ bool DrumGizmo::run(size_t pos, sample_t *samples, size_t nsamples)
 
 			std::memset(resampler_input_buffer[c].get(), 0, MAX_RESAMPLER_BUFFER_SIZE);
 
-			zita[c].inp_data = resampler_input_buffer[c].get();
+			zita[c].set_inp_data(resampler_input_buffer[c].get());
 			std::size_t sample_count =
-				std::ceil((nsamples - (nsamples - zita[c].out_count)) * ratio);
-			getSamples(c, kitpos, zita[c].inp_data, sample_count);
+				std::ceil((nsamples - (nsamples - zita[c].get_out_count())) * ratio);
+			getSamples(c, kitpos, zita[c].get_inp_data(), sample_count);
 
-			zita[c].inp_count = sample_count;
+			zita[c].set_inp_count(sample_count);
 			zita[c].process();
 			if(!internal)
 			{
@@ -244,7 +259,7 @@ bool DrumGizmo::run(size_t pos, sample_t *samples, size_t nsamples)
 	return true;
 }
 
-void DrumGizmo::renderSampleEvent(EventSample& evt, int pos, sample_t *s, std::size_t sz)
+void DrumGizmo::renderSampleEvent(SampleEvent& evt, int pos, sample_t *s, std::size_t sz)
 {
 	size_t n = 0; // default start point is 0.
 
@@ -322,85 +337,73 @@ void DrumGizmo::getSamples(int ch, int pos, sample_t* s, size_t sz)
 	const auto enable_bleed_control = settings.enable_bleed_control.load();
 	const auto master_bleed = settings.master_bleed.load();
 
-	std::vector< Event* > erase_list;
-	std::list< Event* >::iterator i = activeevents[ch].begin();
-	for(; i != activeevents[ch].end(); ++i)
+	EventIDs to_remove;
+	for(auto& sample_event : events_ds.iterateOver<SampleEvent>(ch))
 	{
 		bool removeevent = false;
 
-		Event* event = *i;
-		Event::type_t type = event->getType();
-		switch(type)
+		AudioFile& af = *sample_event.file;
+
+		if(!af.isLoaded() || !af.isValid() || (s == nullptr))
 		{
-		case Event::sample:
-			{
-				EventSample& evt = *static_cast<EventSample*>(event);
-				AudioFile& af = *evt.file;
-
-				if(!af.isLoaded() || !af.isValid() || (s == nullptr))
-				{
-					removeevent = true;
-					break;
-				}
-
-				if(evt.offset > (pos + sz))
-				{
-					// Don't handle event now. It is scheduled for a future iteration.
-					continue;
-				}
-
-				if(evt.cache_id == CACHE_NOID)
-				{
-					size_t initial_chunksize = (pos + sz) - evt.offset;
-					evt.buffer = audio_cache.open(af, initial_chunksize,
-					                              af.filechannel, evt.cache_id);
-					if((af.mainState() == main_state_t::is_not_main) &&
-					   enable_bleed_control)
-					{
-						evt.scale *= master_bleed;
-					}
-
-					evt.buffer_size = initial_chunksize;
-					evt.sample_size = af.size;
-				}
-
-				{
-					std::lock_guard<std::mutex> guard(af.mutex);
-
-					renderSampleEvent(evt, pos, s, sz);
-
-					if((evt.t >= evt.sample_size) || (evt.rampdown_count == 0))
-					{
-						removeevent = true;
-					}
-
-					if(evt.buffer_ptr >= evt.buffer_size && removeevent == false)
-					{
-						evt.buffer_size = sz;
-						evt.buffer = audio_cache.next(evt.cache_id, evt.buffer_size);
-						evt.buffer_ptr = 0;
-					}
-
-					if(removeevent)
-					{
-						audio_cache.close(evt.cache_id);
-					}
-				}
-			}
+			removeevent = true;
 			break;
 		}
 
+		if(sample_event.offset > (pos + sz))
+		{
+			// Don't handle event now. It is scheduled for a future iteration.
+			continue;
+		}
+
+		if(sample_event.cache_id == CACHE_NOID)
+		{
+			size_t initial_chunksize = (pos + sz) - sample_event.offset;
+			sample_event.buffer = audio_cache.open(af, initial_chunksize,
+										  af.filechannel, sample_event.cache_id);
+			if((af.mainState() == main_state_t::is_not_main) &&
+			   enable_bleed_control)
+			{
+				sample_event.scale *= master_bleed;
+			}
+
+			sample_event.buffer_size = initial_chunksize;
+			sample_event.sample_size = af.size;
+		}
+
+		{
+			// TODO: We should make all audiofiles reference counted and get rid of this lock.
+			std::lock_guard<std::mutex> guard(af.mutex);
+
+			renderSampleEvent(sample_event, pos, s, sz);
+
+			if((sample_event.t >= sample_event.sample_size) || (sample_event.rampdown_count == 0))
+			{
+				removeevent = true;
+			}
+
+			if(sample_event.buffer_ptr >= sample_event.buffer_size && !removeevent)
+			{
+				sample_event.buffer_size = sz;
+				sample_event.buffer = audio_cache.next(sample_event.cache_id, sample_event.buffer_size);
+				sample_event.buffer_ptr = 0;
+			}
+
+			if(removeevent)
+			{
+				audio_cache.close(sample_event.cache_id);
+			}
+		}
+
 		if(removeevent)
 		{
-			erase_list.push_back(event); // don't delete until we are out of the loop.
-			continue;
+			to_remove.push_back(sample_event.id); // don't delete until we are out of the loop.
 		}
 	}
 
-	for(auto& event : erase_list)
+	for(auto event_id : to_remove)
 	{
-		activeevents[ch].remove(event);
-		delete event;
+		events_ds.remove(event_id);
 	}
 }
 
@@ -426,7 +429,7 @@ float DrumGizmo::samplerate()
 	return settings.samplerate.load();
 }
 
-void DrumGizmo::setSamplerate(float samplerate)
+void DrumGizmo::setSamplerate(float samplerate, float resampling_quality)
 {
 	DEBUG(dgeditor, "%s samplerate: %f\n", __PRETTY_FUNCTION__, samplerate);
 	settings.samplerate.store(samplerate);
@@ -437,7 +440,7 @@ void DrumGizmo::setSamplerate(float samplerate)
 	auto input_fs = settings.drumkit_samplerate.load();
 	auto output_fs = samplerate;
 	ratio = input_fs / output_fs;
-	settings.resamplig_recommended.store(ratio != 1.0);
+	settings.resampling_recommended.store(ratio != 1.0);
 
 	// TODO: Only reallocate the actual amount of samples needed based on the
 	// ratio and the framesize.
@@ -450,18 +453,20 @@ void DrumGizmo::setSamplerate(float samplerate)
 	{
 		zita[c].reset();
 		auto nchan = 1u; // mono
-		auto hlen = 72u; // 16 ≤ hlen ≤ 96
+		// 16 ≤ hlen ≤ 96 - default is 72, q: 0.7f
+		resampling_quality = std::max(0.0f, std::min(1.0f, resampling_quality));
+		std::size_t hlen = 16 + (96 - 16) * resampling_quality;
 		zita[c].setup(input_fs, output_fs, nchan, hlen);
 
 		// Prefill
 		auto null_size = zita[c].inpsize() - 1;// / 2 - 1;
-		zita[c].inp_data = nullptr;
-		zita[c].inp_count = null_size;
+		zita[c].set_inp_data(nullptr);
+		zita[c].set_inp_count(null_size);
 
 		constexpr auto sz = 4096 * 16;
 		sample_t s[sz];
-		zita[c].out_data = s;
-		zita[c].out_count = sz;
+		zita[c].set_out_data(s);
+		zita[c].set_out_count(sz);
 
 		zita[c].process();
 	}
