@@ -29,17 +29,19 @@
 #include <string>
 #include <list>
 #include <mutex>
+#include <vector>
 
 #include "thread.h"
-#include "semaphore.h"
+#include "sem.h"
 
 #include "drumkit.h"
 #include "settings.h"
 #include "audioinputengine.h"
-#include "chresampler.h"
-#include "memchecker.h"
 #include "audiocache.h"
 
+struct DrumkitDOM;
+struct InstrumentDOM;
+
 //! This class is responsible for loading the drumkits in its own thread.
 //! All interaction calls are simply modifying queues and not doing any
 //! work in-sync with the caller.
@@ -50,7 +52,7 @@ class DrumKitLoader
 {
 public:
 	DrumKitLoader(Settings& settings, DrumKit& kit, AudioInputEngine& ie,
-	              Resamplers& resamplers, Random& rand, AudioCache& audio_cache);
+	              Random& rand, AudioCache& audio_cache);
 
 	~DrumKitLoader();
 
@@ -66,7 +68,7 @@ public:
 	//! Signal the loader to start loading all audio files contained in the kit.
 	//! All other AudioFiles in queue will be removed before the new ones are
 	//! scheduled.
-	void loadKit(DrumKit *kit);
+	void loadKitAudio(const DrumKit& kit);
 
 	//! Skip all queued AudioFiles.
 	void skip();
@@ -89,9 +91,10 @@ protected:
 	SettingsGetter getter;
 	DrumKit& kit;
 	AudioInputEngine& ie;
-	Resamplers& resamplers;
-	MemChecker memchecker;
+	//MemChecker memchecker;
 	Random& rand;
 	AudioCache& audio_cache;
 	std::size_t preload_samples{std::numeric_limits<std::size_t>::max()};
+
+	LogFunction logger;
 };
