@@ -32,25 +32,68 @@
 
 #include "instrument.h"
 
-#include "staminafilter.h"
 #include "latencyfilter.h"
+#include "powermapfilter.h"
+#include "staminafilter.h"
 #include "velocityfilter.h"
 
 #include "cpp11fix.h"
 
+class VelocityStorer
+	: public InputFilter
+{
+public:
+	VelocityStorer(float& original_velocity)
+		: original_velocity(original_velocity)
+	{
+	}
+
+	bool filter(event_t& event, std::size_t pos) override
+	{
+		original_velocity = event.velocity;
+		return true;
+	}
+
+private:
+	float& original_velocity;
+};
+
+class Reporter
+	: public InputFilter
+{
+public:
+	Reporter(Settings& settings, float& original_velocity)
+		: settings(settings)
+		, original_velocity(original_velocity)
+	{
+	}
+
+	bool filter(event_t& event, std::size_t pos) override
+	{
+		settings.velocity_modifier_current.store(event.velocity / original_velocity);
+		return true;
+	}
+
+private:
+	Settings& settings;
+	float& original_velocity;
+};
+
 InputProcessor::InputProcessor(Settings& settings,
                                DrumKit& kit,
-                               std::list<Event*>* activeevents,
+                               EventsDS& events_ds,
                                Random& random)
 	: kit(kit)
-	, activeevents(activeevents)
-	, is_stopping(false)
+	, events_ds(events_ds)
 	, settings(settings)
 {
 	// Build filter list
+	filters.emplace_back(std::make_unique<PowermapFilter>(settings));
+	filters.emplace_back(std::make_unique<VelocityStorer>(original_velocity));
 	filters.emplace_back(std::make_unique<StaminaFilter>(settings));
 	filters.emplace_back(std::make_unique<LatencyFilter>(settings, random));
 	filters.emplace_back(std::make_unique<VelocityFilter>(settings, random));
+	filters.emplace_back(std::make_unique<Reporter>(settings, original_velocity));
 }
 
 bool InputProcessor::process(std::vector<event_t>& events,
@@ -96,8 +139,68 @@ std::size_t InputProcessor::getLatency() const
 	return latency;
 }
 
-bool InputProcessor::processOnset(event_t& event,
-                                  std::size_t pos,
+//! Applies choke with rampdown time in ms to event starting at offset.
+static void applyChoke(Settings& settings, SampleEvent& event,
+                       double length_ms, timepos_t offset)
+{
+	std::size_t ramp_length = (length_ms / 1000.) * settings.samplerate.load();
+	event.rampdown_count = ramp_length;
+	event.rampdown_offset = offset;
+	event.ramp_length = ramp_length;
+}
+
+//! Applies choke group actions to active events based on the input event
+static void applyChokeGroup(Settings& settings, DrumKit& kit,
+                            Instrument& instr, event_t& event,
+                            EventsDS& events_ds)
+{
+	std::size_t instrument_id = event.instrument;
+	if(instr.getGroup() == "")
+	{
+		return;
+	}
+
+	// Add event to ramp down all existing events with the same groupname.
+	for(const auto& ch : kit.channels)
+	{
+		for(auto& event_sample : events_ds.iterateOver<SampleEvent>(ch.num))
+		{
+			if(event_sample.group == instr.getGroup() &&
+			   event_sample.instrument_id != instrument_id &&
+			   event_sample.rampdown_count == -1) // Only if not already ramping.
+			{
+				// Fixed group rampdown time of 68ms, independent of samplerate
+				applyChoke(settings, event_sample, 68, event.offset);
+			}
+		}
+	}
+}
+
+//! Applies directed choke actions to active events based on the input event
+static void applyDirectedChoke(Settings& settings, DrumKit& kit,
+                               Instrument& instr, event_t& event,
+                               EventsDS& events_ds)
+{
+	for(const auto& choke : instr.getChokes())
+	{
+		// Add event to ramp down all existing events with the same groupname.
+		for(const auto& ch : kit.channels)
+		{
+			for(auto& event_sample : events_ds.iterateOver<SampleEvent>(ch.num))
+			{
+				if(choke.instrument_id == event_sample.instrument_id &&
+				   event_sample.rampdown_count == -1) // Only if not already ramping.
+				{
+					// choke.choketime is in ms
+					applyChoke(settings, event_sample, choke.choketime, event_sample.offset);
+				}
+			}
+		}
+
+	}
+}
+
+bool InputProcessor::processOnset(event_t& event, std::size_t pos,
                                   double resample_ratio)
 {
 	if(!kit.isValid())
@@ -119,7 +222,7 @@ bool InputProcessor::processOnset(event_t& event,
 		return false;
 	}
 
-	auto const original_level = event.velocity;
+	original_velocity = event.velocity;
 	for(auto& filter : filters)
 	{
 		// This line might change the 'event' variable
@@ -131,56 +234,11 @@ bool InputProcessor::processOnset(event_t& event,
 		}
 	}
 
-	if(instr->getGroup() != "")
-	{
-		// Add event to ramp down all existing events with the same groupname.
-		for(const auto& ch : kit.channels)
-		{
-			for(auto active_event : activeevents[ch.num])
-			{
-				if(active_event->getType() == Event::sample)
-				{
-					auto& event_sample = *static_cast<EventSample*>(active_event);
-					if(event_sample.group == instr->getGroup() &&
-					   event_sample.instrument_id != instrument_id &&
-					   event_sample.rampdown_count == -1) // Only if not already ramping.
-					{
-						// Fixed group rampdown time of 68ms, independent of samplerate
-						std::size_t ramp_length = (68./1000.)*settings.samplerate.load();
-						event_sample.rampdown_count = ramp_length;
-						event_sample.rampdown_offset = event.offset;
-						event_sample.ramp_length = ramp_length;
-					}
-				}
-			}
-		}
-	}
+	// Mute other instruments in the same instrument/choke group
+	applyChokeGroup(settings, kit, *instr, event, events_ds);
 
-	for(const auto& choke : instr->getChokes())
-	{
-		// Add event to ramp down all existing events with the same groupname.
-		for(const auto& ch : kit.channels)
-		{
-			for(auto active_event : activeevents[ch.num])
-			{
-				if(active_event->getType() == Event::sample)
-				{
-					auto& event_sample = *static_cast<EventSample*>(active_event);
-					if(choke.instrument_id == event_sample.instrument_id &&
-					   event_sample.rampdown_count == -1) // Only if not already ramping.
-					{
-						// Choketime is in ms
-						std::size_t ramp_length =
-							(choke.choketime / 1000.0) * settings.samplerate.load();
-						event_sample.rampdown_count = ramp_length;
-						event_sample.rampdown_offset = event.offset;
-						event_sample.ramp_length = ramp_length;
-					}
-				}
-			}
-		}
-
-	}
+	// Apply directed chokes to mute other instruments if needed
+	applyDirectedChoke(settings, kit, *instr, event, events_ds);
 
 	auto const power_max = instr->getMaxPower();
 	auto const power_min = instr->getMinPower();
@@ -194,9 +252,16 @@ bool InputProcessor::processOnset(event_t& event,
 		return false;
 	}
 
-	auto const selected_level = (sample->getPower() - power_min)/power_span;
-	settings.velocity_modifier_current.store(selected_level/original_level);
+	if(settings.enable_voice_limit.load())
+	{
+		limitVoices(instrument_id,
+		            settings.voice_limit_max.load(),
+		            settings.voice_limit_rampdown.load());
+	}
 
+	//Given that audio files could be invalid, maybe we must add the new
+	//group just before adding the first new sample...
+	bool new_group_added = false;
 	for(Channel& ch: kit.channels)
 	{
 		const auto af = sample->getAudioFile(ch);
@@ -207,15 +272,21 @@ bool InputProcessor::processOnset(event_t& event,
 		else
 		{
 			//DEBUG(inputprocessor, "Adding event %d.\n", event.offset);
-			auto evt = new EventSample(ch.num, 1.0, af, instr->getGroup(),
-			                           instrument_id);
-			evt->offset = (event.offset + pos) * resample_ratio;
-			if(settings.normalized_samples.load() && sample->getNormalized())
+			if(!new_group_added)
 			{
-				evt->scale *= event.velocity;
+				new_group_added=true;
+				events_ds.startAddingNewGroup(instrument_id);
 			}
 
-			activeevents[ch.num].push_back(evt);
+			auto& event_sample =
+				events_ds.emplace<SampleEvent>(ch.num, ch.num, 1.0, af,
+				                               instr->getGroup(), instrument_id);
+
+			event_sample.offset = (event.offset + pos) * resample_ratio;
+			if(settings.normalized_samples.load() && sample->getNormalized())
+			{
+				event_sample.scale *= event.velocity;
+			}
 		}
 	}
 
@@ -259,20 +330,13 @@ bool InputProcessor::processChoke(event_t& event,
 	// Add event to ramp down all existing events with the same groupname.
 	for(const auto& ch : kit.channels)
 	{
-		for(auto active_event : activeevents[ch.num])
+		for(auto& event_sample : events_ds.iterateOver<SampleEvent>(ch.num))
 		{
-			if(active_event->getType() == Event::sample)
+			if(event_sample.instrument_id == instrument_id &&
+			   event_sample.rampdown_count == -1) // Only if not already ramping.
 			{
-				auto& event_sample = *static_cast<EventSample*>(active_event);
-				if(event_sample.instrument_id != instrument_id &&
-				   event_sample.rampdown_count == -1) // Only if not already ramping.
-				{
-					// Fixed group rampdown time of 68ms, independent of samplerate
-					std::size_t ramp_length = (68./1000.)*settings.samplerate.load();
-					event_sample.rampdown_count = ramp_length;
-					event_sample.rampdown_offset = event.offset;
-					event_sample.ramp_length = ramp_length;
-				}
+				// Fixed group rampdown time of 68ms, independent of samplerate
+				applyChoke(settings, event_sample, 68, event_sample.offset);
 			}
 		}
 	}
@@ -293,7 +357,7 @@ bool InputProcessor::processStop(event_t& event)
 		int num_active_events = 0;
 		for(auto& ch: kit.channels)
 		{
-			num_active_events += activeevents[ch.num].size();
+			num_active_events += events_ds.numberOfEvents(ch.num);
 		}
 
 		if(num_active_events == 0)
@@ -305,3 +369,68 @@ bool InputProcessor::processStop(event_t& event)
 
 	return true;
 }
+
+void InputProcessor::limitVoices(std::size_t instrument_id,
+                                 std::size_t max_voices,
+                                 float rampdown_time)
+{
+	const auto& group_ids=events_ds.getSampleEventGroupIDsOf(instrument_id);
+
+	if(group_ids.size() <= max_voices)
+	{
+		return;
+	}
+
+	//Filter out ramping events...
+	auto filter_ramping_predicate =
+		[this](EventGroupID group_id) -> bool
+		{
+			const auto& event_ids=events_ds.getEventIDsOf(group_id);
+			//TODO: This should not happen.
+			if(!event_ids.size())
+			{
+				return false;
+			}
+
+			const auto&	sample=events_ds.get<SampleEvent>(event_ids[0]);
+			return !sample.rampdownInProgress();
+		};
+
+	EventGroupIDs non_ramping;
+	std::copy_if(std::begin(group_ids),
+	             std::end(group_ids),
+	             std::back_inserter(non_ramping), filter_ramping_predicate);
+
+	if(!non_ramping.size())
+	{
+		return;
+	}
+
+	//Let us get the eldest...
+	//TODO: where is the playhead? Should we add it to the offset?
+	auto compare_event_offsets =
+		[this](EventGroupID a, EventGroupID b)
+		{
+			const auto& event_ids_a=events_ds.getEventIDsOf(a);
+			const auto& event_ids_b=events_ds.getEventIDsOf(b);
+
+			const auto&	sample_a=events_ds.get<SampleEvent>(event_ids_a[0]);
+			const auto& sample_b=events_ds.get<SampleEvent>(event_ids_b[0]);
+			return sample_a.offset < sample_b.offset;
+		};
+
+	auto it = std::min_element(std::begin(non_ramping),
+	                           std::end(non_ramping),
+	                           compare_event_offsets);
+	if(it == std::end(non_ramping))
+	{
+		return;
+	}
+
+	const auto& event_ids = events_ds.getEventIDsOf(*it);
+	for(const auto& event_id : event_ids)
+	{
+		auto& sample=events_ds.get<SampleEvent>(event_id);
+		applyChoke(settings, sample, rampdown_time, sample.offset);
+	}
+}
