@@ -33,7 +33,7 @@
 Instrument::Instrument(Settings& settings, Random& rand)
 	: settings(settings)
 	, rand(rand)
-	, powerlist(rand)
+	, sample_selection(settings, rand, powerlist)
 {
 	DEBUG(instrument, "new %p\n", this);
 	mod = 1.0;
@@ -54,31 +54,27 @@ bool Instrument::isValid() const
 	return this == magic;
 }
 
-Sample* Instrument::sample(level_t level, size_t pos)
+const Sample* Instrument::sample(level_t level, size_t pos)
 {
-	Sample *sample = nullptr;
-
 	if(version >= VersionStr("2.0"))
 	{
 		// Version 2.0
-		sample = powerlist.get(level * mod);
+		return sample_selection.get(level * mod, pos);
 	}
 	else
 	{
 		// Version 1.0
-		std::vector<Sample*> s = samples.get(level * mod);
+		auto s = samples.get(level * mod);
 		if(s.size() == 0)
 		{
 			return nullptr;
 		}
 
-		sample = rand.choose(s);
+		return rand.choose(s);
 	}
-
-	return sample;
 }
 
-void Instrument::addSample(level_t a, level_t b, Sample* s)
+void Instrument::addSample(level_t a, level_t b, const Sample* s)
 {
 	samples.insert(a, b, s);
 }
@@ -95,20 +91,26 @@ void Instrument::finalise()
 		}
 
 		powerlist.finalise();
+		sample_selection.finalise();
 	}
 }
 
-std::string Instrument::getName() const
+std::size_t Instrument::getID() const
+{
+	return id;
+}
+
+const std::string& Instrument::getName() const
 {
 	return _name;
 }
 
-std::string Instrument::getDescription() const
+const std::string& Instrument::getDescription() const
 {
 	return _description;
 }
 
-std::string Instrument::getGroup() const
+const std::string& Instrument::getGroup() const
 {
 	return _group;
 }
@@ -120,7 +122,38 @@ void Instrument::setGroup(const std::string& g)
 
 std::size_t Instrument::getNumberOfFiles() const
 {
+	DEBUG(instrument, "audiofiles.size() %d", (int)audiofiles.size());
+
 	// Note: Each AudioFile instance contains just a single channel even for
 	// multi-channel files.
 	return audiofiles.size();
 }
+
+float Instrument::getMaxPower() const
+{
+	if(version >= VersionStr("2.0"))
+	{
+		return powerlist.getMaxPower();
+	}
+	else
+	{
+		return 1.0f;
+	}
+}
+
+float Instrument::getMinPower() const
+{
+	if(version >= VersionStr("2.0"))
+	{
+		return powerlist.getMinPower();
+	}
+	else
+	{
+		return 0.0f;
+	}
+}
+
+const std::vector<Choke>& Instrument::getChokes()
+{
+	return chokes;
+}
