@@ -26,8 +26,8 @@
  */
 #include "powerlist.h"
 
+#include <algorithm>
 #include <stdlib.h>
-
 #include <string.h>
 
 #include <hugin.hpp>
@@ -38,24 +38,22 @@
 #endif
 #include <math.h>
 
-/**
- * Minimum sample set size.
- * Smaller means wider 'velocity groups'.
- * Limited by sample set size, ie. only kicks in if sample set size is smaller
- * than this number.
- */
-unsigned int const MIN_SAMPLE_SET_SIZE = 26u;
+#include "random.h"
+#include "settings.h"
+
+namespace
+{
 
 // Enable to calculate power on old samples without power attribute
 //#define AUTO_CALCULATE_POWER
 unsigned int const LOAD_SIZE = 500u;
 
-PowerList::PowerList(Random& rand)
-	: rand(rand)
+} // end anonymous namespace
+
+PowerList::PowerList()
 {
 	power_max = 0;
 	power_min = 100000000;
-	lastsample = nullptr;
 }
 
 void PowerList::add(Sample* sample)
@@ -67,22 +65,23 @@ void PowerList::add(Sample* sample)
 	samples.push_back(item);
 }
 
-Channel* PowerList::getMasterChannel()
+// FIXME: remove all?
+const Channel* PowerList::getMasterChannel()
 {
-	std::map<Channel*, int> count;
+	std::map<const Channel*, int> count;
 
 	for (auto& item: samples)
 	{
 		Sample* sample{item.sample};
-		Channel* max_channel{nullptr};
+		const Channel* max_channel{nullptr};
 		sample_t max_val{0};
 
 		for (auto& pair: sample->audiofiles)
 		{
-			Channel* c = pair.first;
+			const Channel* c = pair.first;
 			AudioFile* af = pair.second;
 
-			af->load(LOAD_SIZE);
+			af->load(nullptr, LOAD_SIZE);
 
 			float silence{0.f};
 			std::size_t silence_length{4u};
@@ -116,7 +115,7 @@ Channel* PowerList::getMasterChannel()
 		}
 	}
 
-	Channel* master{nullptr};
+	const Channel* master{nullptr};
 	int max_count{-1};
 
 	for (auto& pair: count)
@@ -131,10 +130,11 @@ Channel* PowerList::getMasterChannel()
 	return master;
 }
 
+// FIXME: clean up significantly!
 void PowerList::finalise()
 {
 #ifdef AUTO_CALCULATE_POWER
-	Channel* master_channel = getMasterChannel();
+	const Channel* master_channel = getMasterChannel();
 
 	if(master_channel == nullptr)
 	{
@@ -200,64 +200,21 @@ void PowerList::finalise()
 
 		DEBUG(rand, " - power: %f\n", item.power);
 	}
+
+	std::sort(samples.begin(), samples.end());
 }
 
-Sample* PowerList::get(level_t level)
+const PowerListItems& PowerList::getPowerListItems() const
 {
-	if(!samples.size())
-	{
-		return nullptr; // No samples to choose from.
-	}
+	return samples;
+}
 
-	int retry = 3; // TODO: This must be user controllable via the UI.
+float PowerList::getMaxPower() const
+{
+	return power_max;
+}
 
-	Sample* sample{nullptr};
-
-	float power_span = power_max - power_min;
-
-	// Width is limited to at least 10. Fioxes problem with instrument with a
-	//  sample set smaller than MIN_SAMPLE_SET_SIZE.
-	float width = fmax(samples.size(), MIN_SAMPLE_SET_SIZE);
-
-	// Spread out at most ~2 samples away from center if all samples have a
-	// uniform distribution over the power spectrum (which they probably don't).
-	float stddev = power_span / width;
-
-	// Cut off mean value with stddev/2 in both ends in order to make room for
-	//  downwards expansion on velocity 0 and upwards expansion on velocity 1.
-	float mean = level * (power_span - stddev) + (stddev / 2.0);
-
-	float power{0.f};
-
-	// note: loop is executed once + #retry
-	do
-	{
-		--retry;
-
-		// Select normal distributed value between
-		//  (stddev/2) and (power_span-stddev/2)
-		float lvl = rand.normalDistribution(mean, stddev);
-
-		// Adjust this value to be in range
-		//  (power_min+stddev/2) and (power_max-stddev/2)
-		lvl += power_min;
-
-		DEBUG(rand, "level: %f, lvl: %f (mean: %.2f, stddev: %.2f)\n", level, lvl,
-			mean, stddev);
-
-		for (auto& item: samples)
-		{
-			if (sample == nullptr || std::fabs(item.power - lvl) < std::fabs(power - lvl))
-			{
-				sample = item.sample;
-				power = item.power;
-			}
-		}
-	} while (lastsample == sample && retry >= 0);
-
-	DEBUG(rand, "Found sample with power %f\n", power);
-
-	lastsample = sample;
-
-	return sample;
+float PowerList::getMinPower() const
+{
+	return power_min;
 }
