@@ -24,17 +24,17 @@
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#include "dgunit.h"
+#include <uunit.h>
 
 #include "drumkit_creator.h"
 
 class DrumkitcreatorTest
-	: public DGUnit
+	: public uUnit
 {
 public:
 	DrumkitcreatorTest()
 	{
-		DGUNIT_TEST(DrumkitcreatorTest::testTest);
+		uUNIT_TEST(DrumkitcreatorTest::testTest);
 	}
 
 	DrumkitCreator drumkit_creator;
